@@ -5,7 +5,11 @@ use 5.014; use warnings;
 use Carp;
 use Scalar::Util qw< reftype blessed looks_like_number openhandle >;
 use overload;
+use Variable::Magic;
+
+### IF KEYWORDS {
 use Keyword::Declare;
+### IF KEYWORDS }
 
 sub import {
 
@@ -18,6 +22,8 @@ sub import {
         *{caller.'::'.$export_as} = \&{$exported};
     }
 
+### IF KEYWORDS {
+
     # Create a new subtype of a known type, adding a constraint...
     keyword subtype (
                       Ident $new_type,
@@ -42,9 +48,14 @@ sub import {
         qq{BEGIN{ Dios::Types::_define_subtype('$new_type', '$new_type_params', '$known_type', '$known_type_params') }};
     }
 
+### IF KEYWORDS }
+
 }
 
 my @user_defined_type;
+
+### IF KEYWORDS {
+
 sub _define_subtype {
     my ($new_typename, $new_type_params, $old_typename, $old_type_params, $constraint) = @_;
     $constraint //= sub{1};
@@ -106,6 +117,8 @@ sub _define_subtype {
     push @user_defined_type, $new_type_handler_generator;
 }
 
+### IF KEYWORDS }
+
 sub _error_near ($$;$) {
     my ($where, $what, $previous_errors) = @_;
 
@@ -671,7 +684,7 @@ This document describes Dios::Types version 0.000001
     validate($TYPE, $VALUE, $DESC, @CONSTRAINTS);
 
     # If you don't want exceptions in response to type mismatches, use an eval
-    if (eval{ validate($TYPE, $VALUE }) {
+    if (eval{ validate($TYPE, $VALUE) }) {
         warn "$VALUE not of type $TYPE. Proceeding anyway.";
     }
 
@@ -1264,6 +1277,7 @@ description strings and constraint subroutines) can be passed in any
 order, or even intermixed, as there is no ambiguity in the meaning of
 sub references vs non-references.
 
+=for IF KEYWORDS {
 
 =head2 Declaring subtypes
 
@@ -1340,6 +1354,11 @@ The optional C<where> constraint must be specified as a block of code,
 which is converted to a subroutine that is automatically passed to
 C<validate()> whenever the subtype is used.
 
+B<Note:> if you want to use the other features of this module, but
+don't want the compile-time overheads of this keyword, use the 
+L<Dios::Types::Pure> module instead.
+
+=for IF KEYWORDS }
 
 =head1 DIAGNOSTICS
 
@@ -1423,7 +1442,13 @@ Dios::Types requires no configuration files or environment variables.
 
 Requires Perl 5.14 or later.
 
-Requires the Keyword::Declare and Data::Dump modules.
+Requires the Data::Dump and Variable::Magic modules.
+
+=for IF KEYWORDS {
+
+Also requires the Keyword::Declare module (for the C<subtype> keyword).
+
+=for IF KEYWORDS }
 
 
 =head1 INCOMPATIBILITIES
